@@ -2,7 +2,7 @@ import click
 import pkg_resources
 
 from cloudshell_user_sync import exceptions
-from cloudshell_user_sync.commands import run_scheduler, run_service, set_config, set_credential, set_mapping, sync_groups
+from cloudshell_user_sync.commands import set_config, set_credential, set_mapping, sync_groups
 
 
 @click.group()
@@ -22,20 +22,6 @@ def run():
     sync_groups.sync_groups_flow()
 
 
-@cli.command()
-def runscheduler():
-    """Run sync on infinite scheduler"""
-    run_scheduler.run_scheduled_jobs()
-
-
-@cli.command()
-@click.argument("action", required=True, type=click.Choice(["install", "update", "start"], case_sensitive=True))
-def service(action):
-    """Install Windows service to run job automatically"""
-    click.echo(f"Running service '{action}' action")
-    run_service.run_service_flow()
-
-
 @cli.command()
 @click.argument("target", required=False, type=click.Choice(["ldap", "cloudshell", "cs", "service"], case_sensitive=False))
 @click.argument("key", type=str, required=False)
